"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var commonService = require('../commonService');

/**
 * The Microsoft Academic Graph is a heterogeneous graph containing scientific publication records, citation relationships between those publications, 
 * as well as authors, institutions, journals, conferences, and fields of study. 
 * This graph is used to power experiences in Bing, Cortana, Word, and in Microsoft Academic.
 * The graph is currently being updated on a weekly basis.
 * @augments commonService
 * {@link https://westus.dev.cognitive.microsoft.com/docs/services/56332331778daf02acc0a50b/operations/565d9001ca73072048922d97|documentation}
 */

var academicKnowledge = function (_commonService) {
    _inherits(academicKnowledge, _commonService);

    /**
     * Constructor.
     * 
     * @param {Object} obj
     * @param {string} obj.apiKey
     * @param {string} obj.endpoint
     */
    function academicKnowledge(_ref) {
        var apiKey = _ref.apiKey,
            endpoint = _ref.endpoint;

        _classCallCheck(this, academicKnowledge);

        var _this = _possibleConstructorReturn(this, _commonService.call(this, { apiKey: apiKey, endpoint: endpoint }));

        _this.endpoints = ["westus.api.cognitive.microsoft.com", "api.labs.cognitive.microsoft.com"];
        return _this;
    }

    /**
     * Calculate the distribution of attribute values for a set of paper entities.
     * @returns {Promise.<object>}
     */


    academicKnowledge.prototype.calcHistogram = function calcHistogram(_ref2) {
        var parameters = _ref2.parameters;


        var operation = {
            "path": "academic/v1.0/calchistogram",
            "method": "GET",
            "operationId": "565d9001ca73072048922d97",
            "parameters": [{
                "name": "expr",
                "description": "A query expression that specifies the entities over which to calculate histograms.",
                "value": null,
                "required": true,
                "type": "queryStringParam",
                "typeName": "string"
            }, {
                "name": "model",
                "description": "Name of the model that you wish to query. Currently, the value defaults to \"latest\".\n",
                "value": "latest",
                "required": false,
                "type": "queryStringParam",
                "typeName": "string"
            }, {
                "name": "attributes",
                "description": "A comma delimited list that specifies the attribute values that are included in the response. Attribute names are case-sensitive.",
                "value": null,
                "required": false,
                "type": "queryStringParam",
                "typeName": "string"
            }, {
                "name": "count",
                "description": "Number of results to return.",
                "value": "",
                "required": false,
                "type": "queryStringParam",
                "typeName": "number"
            }, {
                "name": "offset",
                "description": "Index of the first result to return.",
                "value": "",
                "required": false,
                "type": "queryStringParam",
                "typeName": "number"
            }]
        };

        return this.makeRequest({
            operation: operation,
            parameters: parameters
        });
    };

    /**
     * Calculate the distribution of attribute values for a set of paper entities.
     * @returns {Promise.<object>}
     */
    academicKnowledge.prototype.calcHistogramPost = function calcHistogramPost(_ref3) {
        var body = _ref3.body;


        var operation = {
            "path": "academic/v1.0/calchistogram",
            "method": "POST",
            "operationId": "5951f894d2864531c0129ba2"
        };

        return this.makeRequest({
            operation: operation,
            headers: { 'Content-type': "application/x-www-form-urlencoded" },
            body: body
        });
    };

    /**
     * Return a set of academic entities based on a query expression.
     * @returns {Promise.<object>}
     */
    academicKnowledge.prototype.evaluate = function evaluate(_ref4) {
        var parameters = _ref4.parameters;


        var operation = {
            "path": "academic/v1.0/evaluate",
            "method": "GET",
            "operationId": "565d753be597ed16ac3ffc03",
            "parameters": [{
                "name": "expr",
                "description": "A query expression that specifies which entities should be returned.",
                "value": null,
                "required": true,
                "type": "queryStringParam",
                "typeName": "string"
            }, {
                "name": "model",
                "description": "Name of the model that you wish to query. Currently, the value defaults to \"latest\".\n",
                "value": "latest",
                "required": false,
                "type": "queryStringParam",
                "typeName": "string"
            }, {
                "name": "count",
                "description": "Number of results to return.",
                "value": "10",
                "required": false,
                "type": "queryStringParam",
                "typeName": "number"
            }, {
                "name": "offset",
                "description": "Index of the first result to return.",
                "value": "0",
                "required": false,
                "type": "queryStringParam",
                "typeName": "number"
            }, {
                "name": "orderby",
                "description": "Name of an attribute that is used for sorting the entities. Optionally, ascending/descending can be specified. The format is: name:asc or name:desc.",
                "value": null,
                "required": false,
                "type": "queryStringParam",
                "typeName": "string"
            }, {
                "name": "attributes",
                "description": "A comma delimited list that specifies the attribute values that are included in the response. Attribute names are case-sensitive.",
                "value": "Id",
                "required": false,
                "type": "queryStringParam",
                "typeName": "string"
            }]
        };

        return this.makeRequest({
            operation: operation,
            parameters: parameters
        });
    };

    /**
     * Return a set of academic entities based on a query expression.
     * @returns {Promise.<object>}
     */
    academicKnowledge.prototype.evaluatePost = function evaluatePost(_ref5) {
        var body = _ref5.body;


        var operation = {
            "path": "academic/v1.0/evaluate",
            "method": "POST",
            "operationId": "5951f78363b4fb31286b8ef4"
        };

        return this.makeRequest({
            operation: operation,
            headers: { 'Content-type': "application/x-www-form-urlencoded" },
            body: body
        });
    };

    /**
     * Takes an end user query string (i.e., a query entered by a user of your application) and returns formatted interpretations of user intent 
     * based on the Academic Graph data and the Academic Grammar. To provide an interactive experience, you can call this method repeatedly after each character 
     * entered by the user. In that case, you should set the complete parameter to 1 to enable auto-complete suggestions. 
     * If your application does not want auto-completion, you should set the complete parameter to 0.
     * @returns {Promise.<object>}
     */
    academicKnowledge.prototype.interpret = function interpret(_ref6) {
        var parameters = _ref6.parameters;


        var operation = {
            "path": "academic/v1.0/interpret",
            "method": "GET",
            "operationId": "56332331778daf06340c9666",
            "parameters": [{
                "name": "query",
                "description": "Query entered by user. If complete is set to 1, query will be interpreted as a prefix for generating query auto-completion suggestions.",
                "value": null,
                "required": true,
                "type": "queryStringParam",
                "typeName": "string"
            }, {
                "name": "complete",
                "description": "1 means that auto-completion suggestions are generated based on the grammar and graph data.",
                "value": "0",
                "required": false,
                "type": "queryStringParam",
                "typeName": "string"
            }, {
                "name": "count",
                "description": "Maximum number of interpretations to return.",
                "value": "10",
                "required": false,
                "type": "queryStringParam",
                "typeName": "number"
            }, {
                "name": "offset",
                "description": "Index of the first interpretation to return. For example, count=2&offset=0 returns interpretations 0 and 1. count=2&offset=2 returns interpretations 2 and 3.",
                "value": null,
                "required": false,
                "type": "queryStringParam",
                "typeName": "number"
            }, {
                "name": "timeout",
                "description": "Timeout in milliseconds. Only interpretations found before the timeout has elapsed are returned.",
                "value": null,
                "required": false,
                "type": "queryStringParam",
                "typeName": "number"
            }, {
                "name": "model",
                "description": "Name of the model that you wish to query. Currently, the value defaults to \"latest\".\n",
                "value": "latest",
                "required": false,
                "type": "queryStringParam",
                "typeName": "string"
            }]
        };

        return this.makeRequest({
            operation: operation,
            parameters: parameters
        });
    };

    /**
     * Takes an end user query string (i.e., a query entered by a user of your application) and returns formatted interpretations of user intent 
     * based on the Academic Graph data and the Academic Grammar. To provide an interactive experience, you can call this method repeatedly after each character 
     * entered by the user. In that case, you should set the complete parameter to 1 to enable auto-complete suggestions. 
     * If your application does not want auto-completion, you should set the complete parameter to 0.
     * @returns {Promise.<object>}
     */
    academicKnowledge.prototype.interpretPost = function interpretPost(_ref7) {
        var body = _ref7.body;


        var operation = {
            "path": "academic/v1.0/interpret",
            "method": "POST",
            "operationId": "5951f6260ecf2621902c89e4"
        };

        return this.makeRequest({
            operation: operation,
            headers: { 'Content-type': "application/x-www-form-urlencoded" },
            body: body
        });
    };

    /**
     * Calculate a floating point value based on 2 text inputs
     * @returns {Promise.<object>}
     */
    academicKnowledge.prototype.getSimilarity = function getSimilarity(_ref8) {
        var parameters = _ref8.parameters;


        var operation = {
            "path": "academic/v1.0/similarity",
            "method": "GET",
            "operationId": "58076bdadcf4c40708f83791",
            "parameters": [{
                "name": "s1",
                "description": "String to be compared, input length is bounded by the limitation of the length of URL. When the strings are too long to be processed using GET, use POST instead.",
                "value": null,
                "required": true,
                "type": "queryStringParam",
                "typeName": "string"
            }, {
                "name": "s2",
                "description": "String to be compared, input length is bounded by the limitation of the length of URL. When the strings are too long to be processed using GET, use POST instead.",
                "value": null,
                "required": true,
                "type": "queryStringParam",
                "typeName": "string"
            }]
        };

        return this.makeRequest({
            operation: operation,
            parameters: parameters
        });
    };

    /**
     * Calculate a floating point value based on 2 text inputs
     * @returns {Promise.<object>}
     */
    academicKnowledge.prototype.postSimilarity = function postSimilarity(_ref9) {
        var body = _ref9.body;


        var operation = {
            "path": "academic/v1.0/similarity",
            "method": "POST",
            "operationId": "58172b97dbe2d91538cc000b"
        };

        return this.makeRequest({
            operation: operation,
            headers: { 'Content-type': "application/x-www-form-urlencoded" },
            body: body
        });
    };

    return academicKnowledge;
}(commonService);

module.exports = academicKnowledge;